package ink.wgink.module.wechat.startup;

import ink.wgink.module.wechat.dao.official.account.IOfficialAccountUserDao;
import ink.wgink.module.wechat.manager.OfficialAccountAccessTokenManager;
import ink.wgink.properties.wechat.official.account.OfficialAccountProperties;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

/**
 * When you feel like quitting. Think about why you started
 * 当你想要放弃的时候，想想当初你为何开始
 *
 * @ClassName: WechatStartUp
 * @Description: 微信启动
 * @Author: wanggeng
 * @Date: 2021/4/28 6:40 上午
 * @Version: 1.0
 */
@Component
public class WechatStartUp implements ApplicationRunner {
    private static final Logger LOG = LoggerFactory.getLogger(WechatStartUp.class);
    @Autowired
    private OfficialAccountProperties officialAccountProperties;
    @Autowired
    private IOfficialAccountUserDao officialAccountUserDao;

    @Override
    public void run(ApplicationArguments args) throws Exception {
        initTable();
        new Thread(() -> refreshOfficialAccountAccessToken()).start();
    }

    private void initTable() {
        LOG.debug("创建 wechat_official_account_user 表");
        officialAccountUserDao.createTable();
    }

    @Scheduled(cron = "0 0/5 * * * ?")
    public void refreshOfficialAccountAccessToken() {
        OfficialAccountAccessTokenManager.getInstance().refreshAccessToken(officialAccountProperties);
    }

}
